Testing SimpleTextArea | The Dojo Toolkit

# SimpleTextarea

This is a simple text area that doesn't automatically size itself according to it's content. It can be used inside layout containers.

## Plain textarea (rows=5, cols=50), selectOnClick=true

shichashaw, textarea text baw. onChange: not fired yet!
no value yet!

## Plain textarea with style="height: 300px; width: 300px" rows="" cols=""

I have a style setting rather than rows/cols setting

## In a BorderContainer

This is just some text in the top region. This is just some text in the left region. This is just some text in the center region. This is just some text in the right region. This is just some text in the bottom region.